import java.io.*;
import java.util.*;

public class Tests {
    int nTests = 0;
    static Random rnd;

    private class Test {
        String a;
        String b;

        public Test(String a, String b) {
            this.a = a;
            this.b = b;
        }

        private void checkString(String a) {
            for (int i = 0; i < a.length(); i++)
                if (!('a' <= a.charAt(i) && a.charAt(i) <= 'z')) {
                    throw new AssertionError("bad string: " + a);
                }
        }

        void validate() {
            if (!(1 <= a.length() && a.length() <= Constants.MAX_LEN)) throw new AssertionError();
            if (!(1 <= b.length() && b.length() <= Constants.MAX_LEN)) throw new AssertionError();
            checkString(a);
            checkString(b);
        }

        @Override
        public String toString() {
            return a + System.lineSeparator() + b + System.lineSeparator();
        }
    }

    void writeOne(Test test) throws IOException {
        try (PrintWriter out = new PrintWriter(String.format("%02d", ++nTests))) {
            System.out.println("Writing test " + nTests);
            test.validate();
            out.print(test);
        }
    }

    void write(Test... tests) throws IOException {
        for (Test test : tests) {
            writeOne(test);
        }
    }

    void run() throws IOException {
        rnd = new Random(23917);
        write(HandTests());
        for (int i : new int[]{50, 2000, 100000}) { 
            for (int alpha : new int[]{1, 2, 5, 26}) {
                int n = i - i / 10 + rnd.nextInt(i / 5);
                int m = i - i / 10 + rnd.nextInt(i / 5);
                n = Math.min(n, Constants.MAX_LEN);
                m = Math.min(m, Constants.MAX_LEN);
                write(randomTest(n, m, alpha));
            }
            write(randomTest(i, i, 26));
            write(randomTest(i, i, 2));
            write(randomTest(i, i, 1));
            write(genTue(i));
            for (int j = 0; j < 4; j++) {
                write(genSpecial1(i, j));
            }
        }
    }

    private Test genTue(int n) {
        StringBuilder sba = new StringBuilder();
        StringBuilder sbb = new StringBuilder();

        for (int i = 0; i < n; i++) {
            int bc = 0;
            int j = i;
            while (j != 0) {
                bc += j % 2;
                j /= 2;
            }
            sba.append((char)('a' + bc % 2));
            sbb.append((char)('a' + 1 - bc % 2));
        }
        return new Test(sba.toString(), sbb.toString());
    }
    
    private Test genSpecial1(int n, int mode) {
        StringBuilder sba = new StringBuilder();
        StringBuilder sbb = new StringBuilder();

        for (int i = 0; i < n; i++) {
      if (i < n / 2) {
        sba.append(((mode & 1) == 0) ? 'a' : 'b');
        sbb.append(((mode & 2) == 0) ? 'a' : 'b');
      } else {
        sba.append(((mode & 1) == 0) ? 'b' : 'a');
        sbb.append(((mode & 2) == 0) ? 'b' : 'a');
      }
    }
        return new Test(sba.toString(), sbb.toString());
    }

    public static void main(String[] args) throws IOException {
        new Tests().run();
    }

    private Test randomTest(int n, int m, int alpha) {
        String a = randomString(n, alpha);
        String b = randomString(m, alpha);
        return new Test(a, b);
    }

    private String randomString(int n, int alpha) {
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < n; i++)
            sb.append((char)(rnd.nextInt(alpha) + 'a'));
        return sb.toString();
    }


    private Test[] HandTests() {
        return new Test[] {
                new Test("tree", "heap"),
                new Test("a", "b"),
                new Test("a", "a"),
                new Test("abc", "cba")
        };
    }
}
